Enum e_utils::fs::options::FileAccess
source · #[repr(u32)]pub enum FileAccess {
Empty = 0,
}Expand description
This will override the read, write, and append flags on the OpenOptions structure. This method provides fine-grained control over the permissions to read, write and append data, attributes (like hidden and system), and extended attributes.
Variants
Empty = 0
无权限