FsStats

Struct FsStats 

pub struct FsStats { /* private fields */ }
FsStats contains some common stats about a file system.

Implementations

Source

impl FsStats

pub fn free_space(&self) -> u64

Returns the number of free bytes in the file system containing the provided path.

pub fn available_space(&self) -> u64

Returns the available space in bytes to non-priveleged users in the file system containing the provided path.

pub fn total_space(&self) -> u64

Returns the total space in bytes in the file system containing the provided path.

pub fn allocation_granularity(&self) -> u64

Returns the filesystem’s disk space allocation granularity in bytes. The provided path may be for any file in the filesystem.

On Posix, this is equivalent to the filesystem’s block size. On Windows, this is equivalent to the filesystem’s cluster size.